import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _inherits from "@babel/runtime/helpers/inherits";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

/* eslint-disable @typescript-eslint/no-var-requires */
import React from 'react';
import { mount, render, shallow } from 'enzyme';
import toJson from 'enzyme-to-json';
import Alert from '../../alert';
import localeCN from '../locale/zh_CN';
import localeEN from '../locale/en_US';
import setTheme, { themes } from '../setTheme';
import setPrimaryColor from '../setPrimaryColor';
import { ConfigContext } from '../ConfigProvider';

var TestComponent = /*#__PURE__*/function (_React$Component) {
  _inherits(TestComponent, _React$Component);

  var _super = _createSuper(TestComponent);

  function TestComponent() {
    _classCallCheck(this, TestComponent);

    return _super.apply(this, arguments);
  }

  _createClass(TestComponent, [{
    key: "render",
    value: function render() {
      var theme = this.context.theme;
      return /*#__PURE__*/React.createElement("div", null, theme);
    }
  }]);

  return TestComponent;
}(React.Component);

TestComponent.contextType = ConfigContext;
describe('setTheme', function () {
  afterEach(function () {
    jest.restoreAllMocks();
    document.body.removeAttribute('data-theme');
    document.documentElement.style.cssText = '';
  });
  it('should set dark theme', function () {
    expect.assertions(4 + Object.keys(themes).length);
    var setAttributeSpy = jest.spyOn(document.body, 'setAttribute');
    var setPropertySpy = jest.spyOn(document.documentElement.style, 'setProperty');
    setTheme('dark');
    expect(setAttributeSpy).toBeCalledWith('data-theme', 'dark');
    expect(document.body.getAttribute('data-theme')).toEqual('dark');
    Object.keys(themes).forEach(function (key) {
      expect(setPropertySpy).toBeCalledWith(key, themes[key]);
    });
    expect(document.documentElement.style).toHaveLength(Object.keys(themes).length);
    expect(document.documentElement.style.cssText).toMatchSnapshot();
  });
  it('should set light theme', function () {
    expect.assertions(4 + Object.keys(themes).length);
    var setAttributeSpy = jest.spyOn(document.body, 'setAttribute');
    var removePropertySpy = jest.spyOn(document.documentElement.style, 'removeProperty');
    setTheme('light');
    expect(setAttributeSpy).toBeCalledWith('data-theme', 'light');
    expect(document.body.getAttribute('data-theme')).toBe('light');
    Object.keys(themes).forEach(function (key) {
      expect(removePropertySpy).toBeCalledWith(key);
    });
    expect(document.documentElement.style).toHaveLength(0);
    expect(document.documentElement.style.cssText).toMatchSnapshot();
  });
});
describe('setPrimaryColor', function () {
  afterEach(function () {
    jest.restoreAllMocks();
    document.documentElement.style.cssText = '';
  });
  it('should set primary theme color', function () {
    var setPropertySpy = jest.spyOn(document.documentElement.style, 'setProperty');
    setPrimaryColor('#00bc70');
    expect(setPropertySpy).toBeCalledWith('--theme-primary', '#00bc70');
    expect(setPropertySpy).toBeCalledWith('--theme-primary-dark', 'hsl(155.70000000000005, 100%, 35%)');
    expect(setPropertySpy).toBeCalledWith('--theme-primary-lighter', 'hsl(155.70000000000005, 100%, 95%)');
    expect(setPropertySpy).toBeCalledWith('--button-primary-shadow-color', 'rgba(0, 188, 112, 0.3)');
    expect(document.documentElement.style.cssText).toMatchInlineSnapshot("\"--theme-primary: #00bc70; --theme-primary-dark: hsl(155.70000000000005, 100%, 35%); --theme-primary-lighter: hsl(155.70000000000005, 100%, 95%); --button-primary-shadow-color: rgba(0, 188, 112, 0.3);\"");
  });
});
describe('ConfigProvider', function () {
  describe('snapshot', function () {
    var ConfigProvider;
    beforeEach(function () {
      ConfigProvider = require('../index').default;
    });
    it('renders correctly with zh_CN', function () {
      var wrapper = render( /*#__PURE__*/React.createElement(ConfigProvider, {
        locale: localeCN
      }, /*#__PURE__*/React.createElement(Alert, null)));
      expect(toJson(wrapper)).toMatchSnapshot();
    });
    it('renders correctly with en_US', function () {
      var wrapper = render( /*#__PURE__*/React.createElement(ConfigProvider, {
        locale: localeEN
      }, /*#__PURE__*/React.createElement(Alert, null)));
      expect(toJson(wrapper)).toMatchSnapshot();
    });
  });
  describe('behaviour', function () {
    var mod;
    var ConfigProvider;
    var mSetTheme = jest.fn();
    var mSetPrimaryColor = jest.fn();
    beforeEach(function () {
      jest.resetModules();
      jest.doMock('../setTheme', function () {
        return {
          __esModule: true,
          default: mSetTheme
        };
      });
      jest.doMock('../setPrimaryColor', function () {
        return {
          __esModule: true,
          default: mSetPrimaryColor
        };
      });
      mod = require('../ConfigProvider');
      ConfigProvider = mod.default;
    });
    it('should change runtime locale, set theme, set primary theme color with default value', function () {
      var _mod = mod,
          getRunTimeLocale = _mod.getRunTimeLocale;
      var wrapper = shallow( /*#__PURE__*/React.createElement(ConfigProvider, null, /*#__PURE__*/React.createElement(React.Fragment, null)));
      var actual = getRunTimeLocale();
      expect(actual).toEqual({});
      expect(mSetTheme).toBeCalledWith('light');
      expect(mSetPrimaryColor).toBeCalledWith('#00bc70');
      expect(wrapper.prop('value')).toEqual({
        locale: {},
        theme: 'light',
        primaryColor: '#00bc70'
      });
    });
    it('should accept only one child(a React element)', function () {
      expect(function () {
        return shallow( /*#__PURE__*/React.createElement(ConfigProvider, null, /*#__PURE__*/React.createElement("div", null), /*#__PURE__*/React.createElement("div", null)));
      }).toThrowError('React.Children.only expected to receive a single React element child.');
    });
    it('should get context from ConfigContext provider', function () {
      var wrapper = mount( /*#__PURE__*/React.createElement(ConfigProvider, null, /*#__PURE__*/React.createElement(TestComponent, null)));
      expect(wrapper.find('div').text()).toEqual('light');
    });
    it('should get context from ConfigContext provider', function () {
      var wrapper = mount( /*#__PURE__*/React.createElement(ConfigProvider, null, /*#__PURE__*/React.createElement(ConfigContext.Consumer, null, function (value) {
        return /*#__PURE__*/React.createElement("div", null, value.theme);
      })));
      expect(wrapper.find('div').text()).toEqual('light');
    });
  });
});