/* eslint-disable dot-notation */
import React from 'react';
import { render, mount, shallow } from 'enzyme';
import toJson from 'enzyme-to-json';
import { mocked } from 'ts-jest/utils';
import { Volume as VolumeIcon } from '@zarm-design/icons';
import NoticeBar from '../index';
import { addKeyframe, removeKeyframe, existKeyframe } from '../../utils/keyframes';
import { mockRefReturnValueOnce } from '../../../tests/utils';
import Message from '../../message';
jest.mock('../../utils/keyframes');
var mAddKeyframe = mocked(addKeyframe);
var mRemoveKeyframe = mocked(removeKeyframe);
var mExistKeyframe = mocked(existKeyframe);
describe('NoticeBar', function () {
  describe('snapshot', function () {
    it('renders correctly', function () {
      jest.useFakeTimers();
      var wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, null, "foo"));
      jest.runTimersToTime(3000);
      expect(toJson(wrapper)).toMatchSnapshot();
      wrapper.unmount();
    });
    it('theme', function () {
      var wrapper = render( /*#__PURE__*/React.createElement(NoticeBar, {
        theme: "danger"
      }, "foo"));
      expect(toJson(wrapper)).toMatchSnapshot();
    });
    it('icon', function () {
      var wrapper = render( /*#__PURE__*/React.createElement(NoticeBar, {
        icon: /*#__PURE__*/React.createElement("img", {
          alt: "",
          src: "\\\\static.zhongan.com/website/health/zarm/images/icons/state.png"
        })
      }, "foo"));
      expect(toJson(wrapper)).toMatchSnapshot();
    });
  });
  describe('behaviour', function () {
    afterEach(function () {
      jest.restoreAllMocks();
      jest.clearAllMocks();
    });
    it('should render message component', function () {
      jest.spyOn(NoticeBar.prototype, 'updateScrolling').mockImplementation();
      var wrapper = shallow( /*#__PURE__*/React.createElement(NoticeBar, null));
      var messageWrapper = wrapper.find(Message);
      expect(messageWrapper.exists()).toBeTruthy();
      expect(messageWrapper.props()).toEqual(expect.objectContaining({
        size: 'lg',
        theme: 'warning',
        icon: /*#__PURE__*/React.createElement(VolumeIcon, null),
        hasArrow: false,
        closable: false,
        speed: 50,
        delay: 2000
      }));
    });
    it('should create ref', function () {
      var wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, null));
      expect(wrapper.instance()['wrapper']).toBeTruthy();
      expect(wrapper.instance()['content']).toBeTruthy();
    });
    it('should add keyframe when component mount', function () {
      var keyframeContent;
      mAddKeyframe.mockImplementationOnce(function (_, content) {
        keyframeContent = content;
      });
      mExistKeyframe.mockReturnValueOnce(false);
      mockRefReturnValueOnce(NoticeBar, 'wrapper', 'getBoundingClientRect', {
        width: 50
      });
      mockRefReturnValueOnce(NoticeBar, 'content', 'getBoundingClientRect', {
        width: 100
      });
      var wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, null));
      expect(mExistKeyframe).toBeCalledWith('za-notice-bar-scrolling');
      expect(mAddKeyframe).toBeCalledWith('za-notice-bar-scrolling', keyframeContent);
      expect(wrapper.state('animationDuration')).toEqual(6000);
      expect(wrapper.find('.za-notice-bar__body').prop('style')).toEqual({
        WebkitAnimation: 'za-notice-bar-scrolling 6000ms linear infinite',
        animation: "za-notice-bar-scrolling 6000ms linear infinite"
      });
    });
    it('should remove existed keyframe', function () {
      var keyframeContent;
      mExistKeyframe.mockReturnValueOnce(true);
      mAddKeyframe.mockImplementationOnce(function (_, content) {
        keyframeContent = content;
      });
      mockRefReturnValueOnce(NoticeBar, 'wrapper', 'getBoundingClientRect', {
        width: 50
      });
      mockRefReturnValueOnce(NoticeBar, 'content', 'getBoundingClientRect', {
        width: 100
      });
      var wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, null));
      expect(mExistKeyframe).toBeCalledWith('za-notice-bar-scrolling');
      expect(mRemoveKeyframe).toBeCalledWith('za-notice-bar-scrolling');
      expect(mAddKeyframe).toBeCalledWith('za-notice-bar-scrolling', keyframeContent);
      expect(wrapper.state('animationDuration')).toEqual(6000);
      expect(wrapper.find('.za-notice-bar__body').prop('style')).toEqual({
        WebkitAnimation: 'za-notice-bar-scrolling 6000ms linear infinite',
        animation: "za-notice-bar-scrolling 6000ms linear infinite"
      });
    });
    it('should not update scroll if offset width less than wrap width', function () {
      mockRefReturnValueOnce(NoticeBar, 'wrapper', 'getBoundingClientRect', {
        width: 0
      });
      mockRefReturnValueOnce(NoticeBar, 'content', 'getBoundingClientRect', {
        width: 0
      });
      var wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, null));
      expect(mExistKeyframe).not.toBeCalled();
      expect(mRemoveKeyframe).not.toBeCalled();
      expect(mAddKeyframe).not.toBeCalled();
      expect(wrapper.state('animationDuration')).toEqual(0);
      expect(wrapper.find('.za-notice-bar__body').prop('style')).toBeUndefined();
    });
    it('should update scrolling when component did mount', function () {
      var updateScrollingSpy = jest.spyOn(NoticeBar.prototype, 'updateScrolling').mockImplementation();
      mount( /*#__PURE__*/React.createElement(NoticeBar, null));
      expect(updateScrollingSpy).toBeCalledTimes(1);
    });
    it('should update scrolling when component did update', function () {
      var updateScrollingSpy = jest.spyOn(NoticeBar.prototype, 'updateScrolling').mockImplementation();
      var wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, null));
      wrapper.setState({
        animationDuration: 100
      });
      expect(updateScrollingSpy).toBeCalledTimes(2);
    });
  });
});