/* eslint-disable prefer-destructuring */

/* eslint-disable dot-notation */
import React from 'react';
import { render, mount, shallow } from 'enzyme';
import toJson from 'enzyme-to-json';
import SearchBar from '../index';
import SearchBarOriginal from '../SearchBar';
describe('SearchBar', function () {
  afterEach(function () {
    jest.restoreAllMocks();
    jest.useRealTimers();
  });
  describe('snapshot', function () {
    it('renders correctly', function () {
      var wrapper = render( /*#__PURE__*/React.createElement(SearchBar, {
        shape: "round",
        cancelText: "\u53D6\u6D88",
        placeholder: "\u641C\u7D22"
      }));
      expect(toJson(wrapper)).toMatchSnapshot();
    });
    it('renders defaultValue correctly', function () {
      var wrapper = mount( /*#__PURE__*/React.createElement(SearchBar, {
        shape: "round",
        cancelText: "\u53D6\u6D88",
        placeholder: "\u641C\u7D22"
      }));
      wrapper.setProps({
        defaultValue: '搜索关键字'
      });
      expect(toJson(wrapper)).toMatchSnapshot();
    });
    it('renders onFocus called correctly', function () {
      var onFocus = jest.fn();
      var wrapper = mount( /*#__PURE__*/React.createElement(SearchBar, {
        shape: "round",
        placeholder: "\u641C\u7D22",
        onFocus: onFocus
      }));
      wrapper.find('input[type="search"]').simulate('focus');
      expect(onFocus).toBeCalled();
      expect(toJson(wrapper)).toMatchSnapshot();
    });
    it('renders onChange called correctly', function () {
      var onChange = jest.fn();
      var wrapper = mount( /*#__PURE__*/React.createElement(SearchBar, {
        shape: "round",
        placeholder: "\u641C\u7D22",
        onChange: onChange
      }));
      var input = wrapper.find('input[type="search"]');
      input.simulate('change', {
        target: {
          value: '测试值'
        }
      });
      expect(input.instance()['value']).toEqual('测试值');
      expect(toJson(wrapper)).toMatchSnapshot();
    });
    it('renders onCancel called correctly', function () {
      var onCancel = jest.fn();
      var wrapper = mount( /*#__PURE__*/React.createElement(SearchBar, {
        shape: "round",
        placeholder: "\u641C\u7D22",
        onCancel: onCancel
      }));
      var input = wrapper.find('input[type="search"]');
      input.simulate('focus');
      wrapper.find('.za-search-bar__cancel').simulate('click');
      expect(onCancel).toHaveBeenCalled();
      expect(toJson(wrapper)).toMatchSnapshot();
    });
    it('renders onSubmit called correctly', function () {
      var onSubmit = jest.fn();
      var wrapper = mount( /*#__PURE__*/React.createElement(SearchBar, {
        shape: "round",
        placeholder: "\u641C\u7D22",
        onSubmit: onSubmit
      }));
      var input = wrapper.find('input[type="search"]');
      input.simulate('change', {
        target: {
          value: 'My new value'
        }
      });
      wrapper.find('.za-search-bar__form').simulate('submit');
      expect(onSubmit).toHaveBeenCalled();
      expect(toJson(wrapper)).toMatchSnapshot();
    });
    it('renders onClear called correctly', function () {
      var onClear = jest.fn();
      var wrapper = mount( /*#__PURE__*/React.createElement(SearchBar, {
        onClear: onClear
      }));
      var input = wrapper.find('input[type="search"]');
      input.simulate('change', {
        target: {
          value: 'My new value'
        }
      });
      wrapper.find('i.za-input__clear').simulate('click');
      expect(onClear).toHaveBeenCalled();
      expect(input.instance()['value']).toEqual('');
      expect(toJson(wrapper)).toMatchSnapshot();
    });
  });
  it('should update derived state if props.value changed', function () {
    var wrapper = shallow( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      value: "a"
    }));
    expect(wrapper.state()).toEqual({
      focus: false,
      value: 'a',
      preValue: 'a',
      isOnComposition: false
    });
    wrapper.setProps({
      value: 'b'
    });
    expect(wrapper.state()).toEqual({
      focus: false,
      value: 'b',
      preValue: 'b',
      isOnComposition: false
    });
  });
  it('should not update state if props.value is not changed', function () {
    var wrapper = shallow( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      value: "a"
    }));
    expect(wrapper.state()).toEqual({
      focus: false,
      value: 'a',
      preValue: 'a',
      isOnComposition: false
    });
    wrapper.setProps({
      showCancel: true
    });
    expect(wrapper.state()).toEqual({
      focus: false,
      value: 'a',
      preValue: 'a',
      isOnComposition: false
    });
  });
  it('should calculate the position of cancel ref if props.showCancel is false', function () {
    var getComputedStyleSpy = jest.spyOn(window, 'getComputedStyle').mockReturnValueOnce({
      'margin-left': '10px'
    });
    var cancelRefSymbol = Symbol('cancelRef');
    Object.defineProperty(SearchBarOriginal.prototype, 'cancelRef', {
      get: function get() {
        return this[cancelRefSymbol];
      },
      set: function set(ref) {
        if (ref) {
          jest.spyOn(ref, 'getBoundingClientRect').mockReturnValueOnce({
            width: 20
          });
        }

        this[cancelRefSymbol] = ref;
      },
      configurable: true
    });
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      showCancel: false
    }));
    var cancelRef = wrapper.instance()['cancelRef'];
    expect(getComputedStyleSpy).toBeCalledWith(cancelRef, '');
    expect(cancelRef.style.marginRight).toEqual('-30px');
  });
  it('should calculate the position of cancel ref if props.showCancel is true', function () {
    var getComputedStyleSpy = jest.spyOn(window, 'getComputedStyle');
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      showCancel: true
    }));
    var cancelRef = wrapper.instance()['cancelRef'];
    expect(getComputedStyleSpy).not.toBeCalled();
    expect(cancelRef.style.marginRight).toEqual('0px');
  });
  it('should handle focus animation', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      showCancel: true,
      value: "a"
    }));
    var cancelRef = wrapper.instance()['cancelRef'];
    expect(cancelRef.style.marginRight).toEqual('0px');
    expect(cancelRef.className).toContain('animation-ease');
  });
  it('should handle focus event', function () {
    var mOnFocus = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      onFocus: mOnFocus
    }));
    expect(wrapper.state('focus')).toBeFalsy();
    wrapper.find('input').simulate('focus');
    expect(wrapper.state('focus')).toBeTruthy();
    expect(mOnFocus).toBeCalledTimes(1);
    expect(wrapper.instance()['cancelRef'].className).toContain('animation-ease');
  });
  it('should handle input change event and call props.onChange()', function () {
    var mOnChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      onChange: mOnChange
    }));
    var mEvent = {
      target: {
        value: 'test'
      }
    };
    wrapper.find('input').simulate('change', mEvent);
    expect(mOnChange).toBeCalledWith('test');
  });
  it('should handle input change event but not call props.onChange() if composition start event happens', function () {
    var mOnChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      onChange: mOnChange
    }));
    var mEvent = {
      target: {
        value: 'test'
      }
    };
    var inputWrapper = wrapper.find('input');
    inputWrapper.simulate('compositionstart').simulate('change', mEvent);
    expect(wrapper.state('value')).toEqual('test');
    expect(mOnChange).not.toBeCalled();
  });
  it('should handle composition end event and call props.onChange()', function () {
    var mOnChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      onChange: mOnChange
    }));
    var mEvent = {
      target: {
        value: 'test'
      },
      type: 'compositionend'
    };
    var inputWrapper = wrapper.find('input');
    inputWrapper.simulate('compositionend', mEvent);
    expect(wrapper.state('value')).toEqual('test');
    expect(mOnChange).toBeCalledWith('test');
    expect(mOnChange).toBeCalledTimes(2);
  });
  it('should handle cancel action and trigger blur event', function () {
    var mOnCancel = jest.fn();
    var mOnBlur = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      value: "test",
      onCancel: mOnCancel,
      onBlur: mOnBlur
    }));
    var inputWrapper = wrapper.find('input');
    inputWrapper.simulate('focus');
    expect(wrapper.state('focus')).toBeTruthy();
    wrapper.find('.za-search-bar__cancel').simulate('click');
    expect(wrapper.state('value')).toEqual('');
    expect(wrapper.state('isOnComposition')).toBeFalsy();
    expect(wrapper.state('focus')).toBeFalsy();
    expect(mOnCancel).toBeCalledTimes(1);
    expect(mOnBlur).toBeCalledTimes(1);
  });
  it('should handle clear action and change action', function () {
    var mOnClear = jest.fn();
    var mOnChange = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      value: "test",
      onClear: mOnClear,
      onChange: mOnChange
    }));
    var inputRef = wrapper.instance()['inputRef'];
    var focusSpy = jest.spyOn(inputRef, 'focus');
    wrapper.find('.za-input').childAt(1).invoke('onClick')();
    expect(wrapper.state('value')).toEqual('');
    expect(wrapper.state('isOnComposition')).toBeFalsy();
    expect(mOnClear).toBeCalledWith('');
    expect(mOnChange).toBeCalledWith('');
    expect(focusSpy).toBeCalledTimes(2);
  });
  it('should re-calculate the position of cancel ref if cancel text is changed', function () {
    var calculatePositonSpy = jest.spyOn(SearchBarOriginal.prototype, 'calculatePositon');
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      cancelText: "\u53D6\u6D88"
    }));
    expect(calculatePositonSpy).toBeCalledWith(expect.objectContaining({
      cancelText: '取消'
    }));
    wrapper.setProps({
      cancelText: 'cancel'
    });
    expect(calculatePositonSpy).toBeCalledWith(expect.objectContaining({
      cancelText: 'cancel'
    }));
  });
  it('should re-calculate the position of cancel ref if props.showCancel is changed', function () {
    var calculatePositonSpy = jest.spyOn(SearchBarOriginal.prototype, 'calculatePositon');
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, null));
    expect(calculatePositonSpy).toBeCalledWith(expect.objectContaining({
      showCancel: false
    }));
    wrapper.setProps({
      showCancel: true
    });
    expect(calculatePositonSpy).toBeCalledWith(expect.objectContaining({
      showCancel: true
    }));
  });
  it('should re-calculate the position of cancel ref if props.locale.cancelText is changed', function () {
    var calculatePositonSpy = jest.spyOn(SearchBarOriginal.prototype, 'calculatePositon');
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      locale: {
        cancelText: '取消',
        placeholder: ''
      }
    }));
    expect(calculatePositonSpy).toBeCalledWith(expect.objectContaining({
      locale: {
        cancelText: '取消',
        placeholder: ''
      }
    }));
    wrapper.setProps({
      locale: {
        cancelText: 'cancel',
        placeholder: ''
      }
    });
    expect(calculatePositonSpy).toBeCalledWith(expect.objectContaining({
      locale: {
        cancelText: 'cancel',
        placeholder: ''
      }
    }));
  });
  it('should handle blur event', function () {
    jest.useFakeTimers();
    var mOnBlur = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      onBlur: mOnBlur,
      value: "test"
    }));
    var inputWrapper = wrapper.find('input');
    inputWrapper.simulate('focus');
    expect(wrapper.state('focus')).toBeTruthy();
    inputWrapper.simulate('blur');
    jest.advanceTimersByTime(200);
    expect(wrapper.state('focus')).toBeFalsy();
    expect(mOnBlur).toBeCalledTimes(1);
  });
  it('should handle form submit event', function () {
    var mOnSubmit = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, {
      value: "test",
      onSubmit: mOnSubmit
    }));
    var inputRef = wrapper.instance()['inputRef'];
    var blurSpy = jest.spyOn(inputRef, 'blur');
    var mEvent = {
      preventDefault: jest.fn()
    };
    wrapper.find('form').simulate('submit', mEvent);
    expect(mEvent.preventDefault).toBeCalledTimes(1);
    expect(blurSpy).toBeCalledTimes(1);
    expect(mOnSubmit).toBeCalledWith('test');
  });
  it('should handle composition update event', function () {
    var handleCompositionSpy = jest.spyOn(SearchBarOriginal.prototype, 'handleComposition');
    var wrapper = mount( /*#__PURE__*/React.createElement(SearchBarOriginal, null));
    wrapper.find('input').simulate('compositionupdate');
    expect(handleCompositionSpy).toBeCalledTimes(1);
    expect(handleCompositionSpy).toBeCalledWith(expect.objectContaining({
      type: 'compositionupdate'
    }));
  });
});