# Icon 图标

## 基本用法

```jsx
import { Icon } from 'zarm';

const MyIcon = Icon.createFromIconfont('//at.alicdn.com/t/font_1340918_mk657pke2hj.js'); // generated by iconfont.cn

ReactDOM.render(
  <div className="grid">
    <div className="grid-column">
      <MyIcon type="home" theme="primary" />
      <span>home</span>
    </div>
    <div className="grid-column">
      <MyIcon type="user" theme="primary" />
      <span>user</span>
    </div>
  </div>,
  mountNode,
);
```

## 图标主题

```jsx
import { Icon } from 'zarm';

const MyIcon = Icon.createFromIconfont('//at.alicdn.com/t/font_1340918_mk657pke2hj.js');

ReactDOM.render(
  <div className="grid">
    <div className="grid-column">
      <MyIcon type="home" theme="warning" />
      <span>warning</span>
    </div>
    <div className="grid-column">
      <MyIcon type="home" theme="danger" />
      <span>danger</span>
    </div>
    <div className="grid-column">
      <MyIcon type="home" style={{ color: '#1890ff' }} />
      <span>custom color</span>
    </div>
  </div>,
  mountNode,
);
```

## 图标尺寸

```jsx
import { Icon } from 'zarm';

const MyIcon = Icon.createFromIconfont('//at.alicdn.com/t/font_1340918_mk657pke2hj.js');

ReactDOM.render(
  <div className="grid">
    <div className="grid-column">
      <MyIcon type="home" theme="primary" size="sm" />
      <span>sm</span>
    </div>
    <div className="grid-column">
      <MyIcon type="home" theme="primary" />
      <span>md</span>
    </div>
    <div className="grid-column">
      <MyIcon type="home" theme="primary" size="lg" />
      <span>lg</span>
    </div>
  </div>,
  mountNode,
);
```

## 自定义 Iconfont 图标

我们提供了一个 createFromIconfont 方法，方便开发者调用在 <a href="https://www.iconfont.cn/" target="_blank">iconfont.cn</a> 上自行管理的图标。

其本质上是组件在渲染前会自动引入 iconfont.cn 项目中的图标符号集，并且创建了一个 `<use>` 标签来渲染图标的组件。

详见 <a href="https://www.iconfont.cn/help/detail?spm=a313x.7781069.1998910419.d8d11a391&helptype=code" target="_blank">iconfont.cn 使用帮助</a> 查看如何生成 symbol 代码的 js 地址。

```jsx
import { Icon } from 'zarm';

const MyIcon = Icon.createFromIconfont('//at.alicdn.com/t/font_1340918_mk657pke2hj.js'); // generated by iconfont.cn

ReactDOM.render(
  <div className="grid">
    <div className="grid-column">
      <MyIcon type="home" theme="primary" />
      <span>home</span>
    </div>
    <div className="grid-column">
      <MyIcon type="user" theme="primary" />
      <span>user</span>
    </div>
  </div>,
  mountNode,
);
```

## 自定义 SVG 图标

可以通过配置 <a href="https://github.com/smooth-code/svgr" target="_blank">svgr</a> 来将 svg 图标作为 React 组件导入。

本示例以 webpack 为参考，使用 <a href="https://www.npmjs.com/package/@svgr/webpack" target="_blank">@svgr/webpack</a> 来实现，其他实现方式请参阅 <a href="https://www.smooth-code.com/open-source/svgr/docs/getting-started/" target="_blank">svgr 文档</a>

```js
// webpack.config.js
{
  test: /\.svg(\?v=\d+\.\d+\.\d+)?$/,
  issuer: {
    test: /\.jsx?$/,
  },
  use: [
    {
      loader: 'babel-loader',
    },
    {
      loader: '@svgr/webpack',
      options: {
        babel: false,
        icon: true,
      },
    },
  ],
},
```

```jsx
import { Icon } from 'zarm';
import { ReactComponent as YourSvg } from 'path/to/yourSvg.svg'; // path to your '*.svg' file.

ReactDOM.render(<Icon component={YourSvg} />, mountNode);
```

## API

| 属性      | 类型                                                           | 默认值      | 说明                                                              |
| :-------- | :------------------------------------------------------------- | :---------- | :---------------------------------------------------------------- |
| theme     | string                                                         | 'default'   | 主题，可选值 `default`、`primary`、`success`、`warning`、`danger` |
| size      | string                                                         | 'md'        | 大小，可选值 `sm`、`md`、`lg`                                     |
| type      | string                                                         | -           | 图标类型，可选值详见 demo 的基本用法                              |
| component | React.ComponentType&lt;React.SVGProps&lt;SVGSVGElement&gt;&gt; | -           | 本地 svg 文件，需配合 viewBox 使用                                |
| viewBox   | string                                                         | '0 0 32 32' | 自定义 SVG 图标时，用来设置画布的起始坐标及大小                   |
