"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _betterScroll = _interopRequireDefault(require("better-scroll"));

var _utils = require("ts-jest/utils");

var _wheel = _interopRequireDefault(require("../../wheel"));

var _index = _interopRequireDefault(require("../index"));

var _parseProps = _interopRequireDefault(require("../utils/parseProps"));

// TODO: make mock package for better-scroll package
var bsScrollInstance = {
  on: jest.fn().mockImplementationOnce(function (event, handler) {
    if (event === 'scrollEnd') {
      handler();
    }
  }),
  destroy: jest.fn(),
  getSelectedIndex: jest.fn(),
  refresh: jest.fn(),
  wheelTo: jest.fn(),
  disable: jest.fn(),
  stop: jest.fn()
};
jest.mock('better-scroll', function () {
  return jest.fn(function () {
    return bsScrollInstance;
  });
});
var mockedBScroll = (0, _utils.mocked)(_betterScroll.default);
describe('PickerView', function () {
  afterAll(function () {
    jest.resetAllMocks();
  });
  afterEach(function () {
    jest.restoreAllMocks();
  });
  it('should not render wheels if datasource is empty', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_index.default, null));
    expect(wrapper.find('.za-picker-view__content').children()).toHaveLength(0);
  });
  it('should render wheels if datasource is not empty', function () {
    var dataSource = [{
      label: 'a',
      value: 1
    }, {
      label: 'b',
      value: 2
    }];
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_index.default, {
      dataSource: dataSource
    }));
    expect(wrapper.state('dataSource')).toEqual([[{
      label: 'a',
      value: 1
    }, {
      label: 'b',
      value: 2
    }]]);
    expect(wrapper.find('.za-picker-view__content').children()).toHaveLength(1);
    expect(wrapper.find(_wheel.default).props()).toEqual(expect.objectContaining({
      dataSource: [{
        label: 'a',
        value: 1
      }, {
        label: 'b',
        value: 2
      }],
      value: 1,
      valueMember: 'value',
      itemRender: _index.default.defaultProps.itemRender,
      disabled: false,
      onChange: expect.any(Function),
      stopScroll: false
    }));
  });
  it('should render with correct className', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_index.default, {
      className: "foo"
    }));
    expect(wrapper.at(0).prop('className')).toEqual('za-picker-view foo');
    expect(wrapper.find('.za-picker-view__content')).toHaveLength(1);
    expect(wrapper.find('.za-picker-view__mask')).toHaveLength(2);
    expect(wrapper.find('.za-picker-view__mask--top')).toHaveLength(1);
    expect(wrapper.find('.za-picker-view__mask--bottom')).toHaveLength(1);
  });
  it('should handle value change event and re-render wheels with new props', function () {
    var getSourceSpy = jest.spyOn(_parseProps.default, 'getSource');
    bsScrollInstance.getSelectedIndex.mockReturnValueOnce(1);
    mockedBScroll.mockReturnValueOnce(bsScrollInstance);
    var dataSource = [{
      label: 'a',
      value: 1
    }, {
      label: 'b',
      value: 2
    }];
    var props = {
      onChange: jest.fn(),
      dataSource: dataSource
    };
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_index.default, props));
    expect(bsScrollInstance.on).toBeCalledWith('scrollEnd', expect.any(Function));
    expect(getSourceSpy).toBeCalledWith({
      dataSource: props.dataSource,
      value: [2],
      valueMember: 'value',
      cols: Infinity
    });
    expect(props.onChange).toBeCalledWith([{
      label: 'b',
      value: 2
    }], 0);
    expect(wrapper.state('value')).toEqual([2]);
    expect(wrapper.state('objValue')).toEqual([{
      label: 'b',
      value: 2
    }]);
    expect(wrapper.state('dataSource')).toEqual([[{
      label: 'a',
      value: 1
    }, {
      label: 'b',
      value: 2
    }]]);
    expect(wrapper.find(_wheel.default).props()).toEqual(expect.objectContaining({
      dataSource: [{
        label: 'a',
        value: 1
      }, {
        label: 'b',
        value: 2
      }],
      value: 2,
      valueMember: 'value',
      itemRender: _index.default.defaultProps.itemRender,
      disabled: false,
      onChange: expect.any(Function),
      stopScroll: false
    }));
  });
  it('PickerView render visible', function () {
    var wrapper = (0, _enzyme.render)( /*#__PURE__*/_react.default.createElement(_index.default, {
      dataSource: [{
        value: '1',
        label: '选项一'
      }, {
        value: '2',
        label: '选项二'
      }],
      defaultValue: "1",
      value: "1"
    }));
    expect((0, _enzymeToJson.default)(wrapper)).toMatchSnapshot();
  });
  it('PickerView disabled', function () {
    var onChange = jest.fn();
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_index.default, {
      disabled: true,
      onChange: onChange,
      dataSource: [{
        value: '1',
        label: '选项一'
      }, {
        value: '2',
        label: '选项二'
      }]
    }));
    expect(onChange).not.toBeCalled();
    expect((0, _enzymeToJson.default)(wrapper)).toMatchSnapshot();
  });
});