"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _enzymeToJson = _interopRequireDefault(require("enzyme-to-json"));

var _index = _interopRequireDefault(require("../index"));

var _TabBarItem = _interopRequireDefault(require("../TabBarItem"));

var _badge = _interopRequireDefault(require("../../badge"));

var activeIcon = /*#__PURE__*/_react.default.createElement("div", {
  style: {
    width: '24px',
    height: '24px',
    background: 'url(//cdn-health.zhongan.com/zarm/home-active.svg) top left / 24px 24px no-repeat'
  }
});

var icon = /*#__PURE__*/_react.default.createElement("div", {
  style: {
    width: '24px',
    height: '24px',
    background: 'url(//cdn-health.zhongan.com/zarm/home.svg) top left / 24px 24px no-repeat'
  }
});

describe('TabBarItem', function () {
  it('should render with a badge', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_TabBarItem.default, {
      itemKey: "1",
      badge: {
        theme: 'primary'
      }
    }));
    expect(wrapper.prop('className')).toBe('za-tab-bar__item');
    expect(wrapper.prop('style')).toBeUndefined();
    expect(wrapper.find(_badge.default)).toBeTruthy();
    expect(wrapper.find(_badge.default).prop('theme')).toEqual('primary');
  });
  it('should render with content', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_TabBarItem.default, {
      itemKey: "1",
      title: /*#__PURE__*/_react.default.createElement("h1", null, "test"),
      icon: /*#__PURE__*/_react.default.createElement("span", null, "test icon")
    }));
    expect(wrapper.find('.za-tab-bar__icon')).toBeTruthy();
    expect(wrapper.find('.za-tab-bar__icon').children()).toHaveLength(1);
    expect(wrapper.find('.za-tab-bar__icon').children().at(0).text()).toBe('test icon');
    expect(wrapper.find('.za-tab-bar__icon').children().at(0).type()).toBe('span');
    expect(wrapper.find('.za-tab-bar__title')).toBeTruthy();
    expect(wrapper.find('.za-tab-bar__title').contains( /*#__PURE__*/_react.default.createElement("h1", null, "test"))).toBeTruthy();
  });
  it('should handle change event', function () {
    var mOnChange = jest.fn();
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_TabBarItem.default, {
      itemKey: 1,
      onChange: mOnChange
    }));
    wrapper.simulate('click');
    expect(mOnChange).toBeCalledWith(1);
  });
  it('should render with icon if it is selected', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_TabBarItem.default, {
      itemKey: "1",
      selected: true,
      title: /*#__PURE__*/_react.default.createElement("h1", null, "test"),
      icon: /*#__PURE__*/_react.default.createElement("span", null, "test icon")
    }));
    expect(wrapper.prop('className')).toEqual('za-tab-bar__item za-tab-bar--active');
    expect(wrapper.find('.za-tab-bar__icon').contains( /*#__PURE__*/_react.default.createElement("span", null, "test icon"))).toBeTruthy();
  });
  it('should render with active icon if it is selected', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_TabBarItem.default, {
      itemKey: "1",
      selected: true,
      title: /*#__PURE__*/_react.default.createElement("h1", null, "test"),
      icon: /*#__PURE__*/_react.default.createElement("span", null, "active icon")
    }));
    expect(wrapper.find('.za-tab-bar__icon').contains( /*#__PURE__*/_react.default.createElement("span", null, "active icon"))).toBeTruthy();
  });
  it('should render inline style', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_TabBarItem.default, {
      itemKey: "1",
      style: {
        color: 'red',
        display: 'flex'
      }
    }));
    expect(wrapper.prop('style')).toHaveProperty('color', 'red');
    expect(wrapper.prop('style')).toHaveProperty('display', 'flex');
  });
});
describe('TabBar', function () {
  describe('snapshot', function () {
    it('should render correctly', function () {
      var wrapper = (0, _enzyme.render)( /*#__PURE__*/_react.default.createElement(_index.default, null, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
        itemKey: "home",
        title: "\u4E3B\u9875",
        icon: icon,
        activeIcon: activeIcon
      })));
      expect((0, _enzymeToJson.default)(wrapper)).toMatchSnapshot();
    });
    it('with defaultActiveKey', function () {
      var wrapper = (0, _enzyme.render)( /*#__PURE__*/_react.default.createElement(_index.default, {
        defaultActiveKey: "home"
      }, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
        itemKey: "home",
        title: "\u4E3B\u9875",
        icon: icon,
        activeIcon: activeIcon
      })));
      expect((0, _enzymeToJson.default)(wrapper)).toMatchSnapshot();
    });
    it('with activeKey', function () {
      var wrapper = (0, _enzyme.render)( /*#__PURE__*/_react.default.createElement(_index.default, {
        activeKey: "home"
      }, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
        itemKey: "home",
        title: "\u4E3B\u9875",
        icon: icon,
        activeIcon: activeIcon
      })));
      expect((0, _enzymeToJson.default)(wrapper)).toMatchSnapshot();
    });
  });
  it('should handle change event', function () {
    var onChange = jest.fn();
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_index.default, {
      defaultActiveKey: "home",
      onChange: onChange
    }, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
      itemKey: "home",
      title: "\u4E3B\u9875",
      icon: icon,
      activeIcon: activeIcon
    })));
    wrapper.find('.za-tab-bar__item').first().simulate('click');
    expect(onChange).toBeCalledWith('home');
  });
  it('should select first tab bar item if activeKey and defaultActivceKey are not existed', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_index.default, {
      visible: false,
      className: "test"
    }, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
      itemKey: "home",
      title: "\u4E3B\u9875"
    }), /*#__PURE__*/_react.default.createElement(_index.default.Item, {
      itemKey: "about us",
      title: "\u5173\u4E8E\u6211\u4EEC"
    })));
    expect(wrapper.childAt(0).prop('selected')).toBeTruthy();
    expect(wrapper.childAt(1).prop('selected')).toBeFalsy();
  });
  it('should render icon if selected is false(defaultActivceKey is not equal with itemKey)', function () {
    var onChange = jest.fn();
    var wrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_index.default, {
      defaultActiveKey: "home",
      onChange: onChange
    }, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
      itemKey: "badge",
      title: "\u4E3B\u9875",
      icon: icon,
      activeIcon: activeIcon,
      badge: {
        shape: 'circle',
        text: '3'
      }
    })));
    wrapper.find(_index.default.Item).first().simulate('click');
    expect(onChange).toBeCalledWith('badge');
    expect(wrapper.find('.za-tab-bar__icon').contains(icon)).toBeTruthy();
  });
  it('should selected tab bar item if activeKey is equal with itemKey', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_index.default, {
      defaultActiveKey: "home"
    }, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
      itemKey: "home",
      title: "\u4E3B\u9875"
    })));
    expect(wrapper.find(_index.default.Item).prop('selected')).toBeTruthy();
  });
  it('should use element index as the fallback itemKey', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_index.default, null, /*#__PURE__*/_react.default.createElement(_index.default.Item, null), /*#__PURE__*/_react.default.createElement(_index.default.Item, null)));
    expect(wrapper.childAt(0).prop('itemKey')).toBe(0);
    expect(wrapper.childAt(1).prop('itemKey')).toBe(1);
  });
  it('should have hidden class name if visible prop is false', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_index.default, {
      visible: false,
      className: "test"
    }, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
      itemKey: "home",
      title: "\u4E3B\u9875"
    })));
    expect(wrapper.hasClass('test')).toBeTruthy();
    expect(wrapper.hasClass('za-tab-bar')).toBeTruthy();
    expect(wrapper.hasClass('za-tab-bar--hidden')).toBeTruthy();
  });
  it('should render children with extra props', function () {
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_index.default, {
      visible: false,
      className: "test"
    }, /*#__PURE__*/_react.default.createElement(_index.default.Item, {
      itemKey: "home",
      title: "\u4E3B\u9875"
    }), /*#__PURE__*/_react.default.createElement(_index.default.Item, {
      itemKey: "about us",
      title: "\u5173\u4E8E\u6211\u4EEC"
    })));
    expect(wrapper.childAt(0).props()).toEqual(expect.objectContaining({
      title: '主页',
      itemKey: 'home',
      onChange: expect.any(Function),
      selected: true
    }));
    expect(wrapper.childAt(1).props()).toEqual(expect.objectContaining({
      title: '关于我们',
      itemKey: 'about us',
      onChange: expect.any(Function),
      selected: false
    }));
  });
});