"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _enzyme = require("enzyme");

var _react = _interopRequireDefault(require("react"));

var _trigger = _interopRequireDefault(require("../trigger"));

describe('Trigger', function () {
  afterEach(function () {
    _trigger.default.instanceList = [];
    _trigger.default.count = 0;
    jest.restoreAllMocks();
  });
  describe('static getDerivedStateFromProps', function () {
    it('should return null if visible prop is false and instance list of Trigger component is empty', function () {
      var props = {
        disabled: false,
        visible: true
      };

      var actual = _trigger.default.getDerivedStateFromProps(props);

      expect(actual).toBeNull();
      expect(_trigger.default.instanceList).toEqual([]);
    });
    it('should push onclose function to instance list if visible is true and the onclose function does not exist in instance list', function () {
      var props = {
        disabled: false,
        visible: true,
        onClose: jest.fn()
      };

      var actual = _trigger.default.getDerivedStateFromProps(props);

      expect(actual).toBeNull();
      expect(_trigger.default.instanceList).toEqual([props.onClose]);
    });
  });
  describe('static onKeydown', function () {
    it('should handle escape keyboard event using the last handler of instance list', function () {
      var mHandler = jest.fn(); // eslint-disable-next-line dot-notation

      mHandler['disabled'] = false;
      _trigger.default.instanceList = [mHandler];
      var mEvent = {
        keyCode: 27
      };

      _trigger.default.onKeydown(mEvent);

      expect(mHandler).toBeCalledTimes(1);
    });
    it('should do nothing if the instance list is empty', function () {
      var mEvent = {
        keyCode: 27
      };
      expect(_trigger.default.onKeydown(mEvent)).toBeUndefined();
    });
    it('should do nothing if last handler is disabled', function () {
      var mHandler = jest.fn(); // eslint-disable-next-line dot-notation

      mHandler['disabled'] = true;
      _trigger.default.instanceList = [mHandler];
      var mEvent = {
        keyCode: 27
      };

      _trigger.default.onKeydown(mEvent);

      expect(mHandler).not.toBeCalled();
    });
  });
  it('should add keydown event listener for document.body and increase the counter', function () {
    var addEventListenerSpy = jest.spyOn(document.body, 'addEventListener');
    (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_trigger.default, {
      visible: true,
      disabled: false
    }));
    (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_trigger.default, {
      visible: true,
      disabled: false
    }));
    expect(addEventListenerSpy).toBeCalledWith('keydown', _trigger.default.onKeydown);
    expect(addEventListenerSpy).toBeCalledTimes(1);
    expect(_trigger.default.count).toBe(2);
  });
  it('should remove keydown event handler from document.body and instance list', function () {
    var removeEventListenerSpy = jest.spyOn(document.body, 'removeEventListener');
    var mOnClose = jest.fn();
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_trigger.default, {
      visible: true,
      disabled: false,
      onClose: mOnClose
    }));
    expect(_trigger.default.instanceList).toEqual([mOnClose]);
    expect(_trigger.default.count).toBe(1);
    wrapper.unmount();
    expect(_trigger.default.instanceList).toHaveLength(0);
    expect(_trigger.default.count).toBe(0);
    expect(removeEventListenerSpy).toBeCalledWith('keydown', _trigger.default.onKeydown);
    expect(removeEventListenerSpy).toBeCalledTimes(1);
  });
});